@@ -10,16 +10,17 @@ dimnames(.D) <- list(.names, .names)
 .D[1:length(.mf), 1] <- -1
 .D <- .D[-1,]
 #
-f.vis(.D)
-f.vis(coeff[[1]])
-f.vis(.D %*% coeff[[1]])
+.vis <- F
+f.vis(.D, vis = .vis)
+f.vis(coeff[[1]], vis = .vis)
+f.vis(.D %*% coeff[[1]], vis = .vis)
 #
-f.vis(.coef <- lapply(coeff, function(x) .D %*% x))
-f.vis(covar)
-f.vis(.cov <- lapply(covar, function(x) .D %*% x %*% t(.D)))
+f.vis(.coef <- lapply(coeff, function(x) .D %*% x), vis = .vis)
+f.vis(covar, vis = .vis)
+f.vis(.cov <- lapply(covar, function(x) .D %*% x %*% t(.D)), vis = .vis)
 
 
 return(list(coeff = .coef, covar = .cov))
 
 
-}
\ No newline at end of file
+}
